@@ -9,5 +9,5 @@ def get(num_id=-1,name=7):
     elif num_id == -1:
         return requests.get(api(path='name='+name))
     elif name == 7:
-        return requests.get(api(path='id='+num_id))
+        return requests.get(api(path='id='+str(num_id)))
     
\ No newline at end of file
